@@ -17,14 +17,14 @@ private Q_SLOTS:
         auto stateConfig = KSharedConfig::openStateConfig(QStringLiteral("test_statedatarc"));
 
         // Clean the group at every start
-        stateConfig->deleteGroup("General");
+        stateConfig->deleteGroup(QStringLiteral("General"));
         stateConfig->sync();
 
         // It should have the default value
         QCOMPARE(MyStateConfig().someStateData(), 0);
 
         // the updated value should be read from the generated config class
-        stateConfig->group("General").writeEntry("SomeStateData", 1);
+        stateConfig->group(QStringLiteral("General")).writeEntry("SomeStateData", 1);
         QCOMPARE(MyStateConfig().someStateData(), 1);
 
         // Make sure writing the value works as expected
@@ -33,7 +33,7 @@ private Q_SLOTS:
         QVERIFY(cfg.isSaveNeeded());
         cfg.save();
         stateConfig->reparseConfiguration();
-        QCOMPARE(stateConfig->group("General").readEntry("SomeStateData", -1), 2);
+        QCOMPARE(stateConfig->group(QStringLiteral("General")).readEntry("SomeStateData", -1), 2);
     }
 };
 QTEST_MAIN(TestStateConfig)
