@@ -54,11 +54,11 @@ public:
          * Implied persistent
          * @since 5.51
          */
-        Normal = Persistent
+        Normal = Persistent,
         /**<
-        * Save the entry to the application specific config file without
-        * a locale tag. This is the default.
-        */
+         * Save the entry to the application specific config file without
+         * a locale tag. This is the default.
+         */
 
     };
     /**
@@ -85,18 +85,26 @@ public:
      * @return true if the group exists.
      */
     bool hasGroup(const QString &group) const;
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for hasGroup(const QString&) const
      *
      * @param group name of group to search for, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     bool hasGroup(const char *group) const;
+#endif
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for hasGroup(const QString&) const
      *
      * @param group name of group to search for, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     bool hasGroup(const QByteArray &group) const;
+#endif
 
     /**
      * Returns an object for the named subgroup.
@@ -106,35 +114,51 @@ public:
      * @return config group object for the given group name.
      */
     KConfigGroup group(const QString &group);
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for group(const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     KConfigGroup group(const QByteArray &group);
+#endif
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for group(const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     KConfigGroup group(const char *group);
+#endif
 
     /**
      * Const overload for group(const QString&)
      */
     const KConfigGroup group(const QString &group) const;
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Const overload for group(const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     const KConfigGroup group(const QByteArray &group) const;
+#endif
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Const overload for group(const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     const KConfigGroup group(const char *group) const;
+#endif
 
     /**
      * Delete @p group.
@@ -142,18 +166,26 @@ public:
      * removes any cascaded values from config files earlier in the stack.
      */
     void deleteGroup(const QString &group, WriteConfigFlags flags = Normal);
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for deleteGroup(const QString&, WriteConfigFlags)
      *
      * @param group name of group to delete, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     void deleteGroup(const QByteArray &group, WriteConfigFlags flags = Normal);
+#endif
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for deleteGroup(const QString&, WriteConfigFlags)
      *
      * @param group name of group to delete, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     void deleteGroup(const char *group, WriteConfigFlags flags = Normal);
+#endif
 
     /**
      * Syncs the configuration object that this group belongs to.
@@ -172,7 +204,11 @@ public:
     /**
      * Possible return values for accessMode().
      */
-    enum AccessMode { NoAccess, ReadOnly, ReadWrite };
+    enum AccessMode {
+        NoAccess,
+        ReadOnly,
+        ReadWrite,
+    };
 
     /**
      * Returns the access mode of the app-config object.
@@ -201,32 +237,40 @@ public:
      * @return @c false if the entries in @p group can be modified, otherwise @c true
      */
     bool isGroupImmutable(const QString &group) const;
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for isGroupImmutable(const QString&) const
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     bool isGroupImmutable(const QByteArray &group) const;
+#endif
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for isGroupImmutable(const QString&) const
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     bool isGroupImmutable(const char *group) const;
+#endif
 
 protected:
     KConfigBase();
 
-    /// @param group name of group, encoded in UTF-8
-    virtual bool hasGroupImpl(const QByteArray &group) const = 0;
-    /// @param group name of group, encoded in UTF-8
-    virtual KConfigGroup groupImpl(const QByteArray &group) = 0;
-    /// @param group name of group, encoded in UTF-8
-    virtual const KConfigGroup groupImpl(const QByteArray &group) const = 0;
-    /// @param group name of group, encoded in UTF-8
-    virtual void deleteGroupImpl(const QByteArray &group, WriteConfigFlags flags = Normal) = 0;
-    /// @param group name of group, encoded in UTF-8
-    virtual bool isGroupImmutableImpl(const QByteArray &group) const = 0;
+    /// @param groupName name of group
+    virtual bool hasGroupImpl(const QString &groupName) const = 0;
+    /// @param groupName name of group
+    virtual KConfigGroup groupImpl(const QString &groupName) = 0;
+    /// @param groupName name of group
+    virtual const KConfigGroup groupImpl(const QString &groupName) const = 0;
+    /// @param groupName name of group
+    virtual void deleteGroupImpl(const QString &groupName, WriteConfigFlags flags = Normal) = 0;
+    /// @param groupName name of group
+    virtual bool isGroupImmutableImpl(const QString &groupName) const = 0;
 
     /** Virtual hook, used to add new "virtual" functions while maintaining
      * binary compatibility. Unused in this class.
