@@ -54,12 +54,16 @@ public:
      * @param group name of group
      */
     KConfigGroup(KConfigBase *master, const QString &group);
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for KConfigGroup(KConfigBase*,const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     KConfigGroup(KConfigBase *master, const char *group);
+#endif
 
     /**
      * Construct a read-only config group.
@@ -70,21 +74,29 @@ public:
      * as @p master.
      */
     KConfigGroup(const KConfigBase *master, const QString &group);
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for KConfigGroup(const KConfigBase*,const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     KConfigGroup(const KConfigBase *master, const char *group);
+#endif
 
     /** Overload for KConfigGroup(const KConfigBase*,const QString&) */
     KConfigGroup(const QExplicitlySharedDataPointer<KSharedConfig> &master, const QString &group);
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
     /**
      * Overload for KConfigGroup(const KConfigBase*,const QString&)
      *
      * @param group name of group, encoded in UTF-8
+     * @deprecated Since 5.240, use QString overload
      */
+    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
     KConfigGroup(const QExplicitlySharedDataPointer<KSharedConfig> &master, const char *group);
+#endif
 
     /**
      * Creates a copy of a group.
@@ -140,30 +152,6 @@ public:
      */
     const KConfig *config() const;
 
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Changes the group of the object
-     *
-     * @deprecated Since 5.0
-     * Create another KConfigGroup from the parent of this group instead.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Create another KConfigGroup from the parent of this group")
-    void changeGroup(const QString &group);
-#endif
-
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Overload for changeGroup(const QString&)
-     *
-     * @param group name of group, encoded in UTF-8
-     *
-     * @deprecated Since 5.0.
-     * Create another KConfigGroup from the parent of this group instead.
-     */
-    KCONFIGCORE_DEPRECATED_VERSION(5, 0, "Create another KConfigGroup from the parent of this group")
-    void changeGroup(const char *group);
-#endif
-
     /**
      * Copies the entries in this group to another configuration object
      *
@@ -245,7 +233,7 @@ public:
      * You must turn it into readEntry("...", QColor(Qt::white)).
      *
      * @note Only the following QVariant types are allowed : String,
-     * StringList, List, Font, Point, Rect, Size, Color, Int, UInt, Bool,
+     * StringList, List, Font, Point, PointF, Rect, RectF, Size, SizeF, Color, Int, UInt, Bool,
      * Double, LongLong, ULongLong, DateTime and Date.
      *
      * @param key The key to search for
@@ -647,21 +635,13 @@ public:
      *
      * @param key The key of the entry to revert.
      */
-    // TODO KF6 merge with the other one
-    void revertToDefault(const QString &key);
-    void revertToDefault(const QString &key, WriteConfigFlags pFlag);
+    void revertToDefault(const QString &key, WriteConfigFlags pFlag = WriteConfigFlags());
 
-    // TODO KF6 merge with the other one
-    /**
-     * Overload for revertToDefault(const QString&)
-     * @param key name of key, encoded in UTF-8
-     */
-    void revertToDefault(const char *key);
     /**
      * Overload for revertToDefault(const QString&, WriteConfigFlags)
      * @param key name of key, encoded in UTF-8
      */
-    void revertToDefault(const char *key, WriteConfigFlags pFlag);
+    void revertToDefault(const char *key, WriteConfigFlags pFlag = WriteConfigFlags());
 
     /**
      * Whether a default is specified for an entry in either the
@@ -708,11 +688,11 @@ public:
     QMap<QString, QString> entryMap() const;
 
 protected:
-    bool hasGroupImpl(const QByteArray &group) const override;
-    KConfigGroup groupImpl(const QByteArray &b) override;
-    const KConfigGroup groupImpl(const QByteArray &b) const override;
-    void deleteGroupImpl(const QByteArray &group, WriteConfigFlags flags) override;
-    bool isGroupImmutableImpl(const QByteArray &aGroup) const override;
+    bool hasGroupImpl(const QString &groupName) const override;
+    KConfigGroup groupImpl(const QString &groupName) override;
+    const KConfigGroup groupImpl(const QString &groupName) const override;
+    void deleteGroupImpl(const QString &groupName, WriteConfigFlags flags) override;
+    bool isGroupImmutableImpl(const QString &groupName) const override;
 
 private:
     QExplicitlySharedDataPointer<KConfigGroupPrivate> d;
@@ -734,6 +714,8 @@ private:
     friend class KServiceAction;
 };
 
+Q_DECLARE_TYPEINFO(KConfigGroup, Q_RELOCATABLE_TYPE);
+
 #define KCONFIGGROUP_ENUMERATOR_ERROR(ENUM) "The Qt MetaObject system does not seem to know about \"" ENUM "\" please use Q_ENUM or Q_FLAG to register it."
 
 /**
@@ -756,10 +738,6 @@ private:
         const QByteArray M_data = readEntry(key, QByteArray(M_enum.valueToKey(def)));                                                                          \
         return static_cast<Class::Enum>(M_enum.keyToValue(M_data.constData()));                                                                                \
     }                                                                                                                                                          \
-    inline Class::Enum KCONFIGCORE_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Enum &def)                               \
-    {                                                                                                                                                          \
-        return group.readEntry(key, def);                                                                                                                      \
-    }                                                                                                                                                          \
     template<>                                                                                                                                                 \
     void KConfigGroup::writeEntry(const char *key, const Class::Enum &value, KConfigBase::WriteConfigFlags flags)                                              \
     {                                                                                                                                                          \
@@ -769,13 +747,6 @@ private:
             qFatal(KCONFIGGROUP_ENUMERATOR_ERROR(#Enum));                                                                                                      \
         const QMetaEnum M_enum = M_obj->enumerator(M_index);                                                                                                   \
         writeEntry(key, QByteArray(M_enum.valueToKey(value)), flags);                                                                                          \
-    }                                                                                                                                                          \
-    inline void KCONFIGCORE_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                    \
-                                                       const char *key,                                                                                        \
-                                                       const Class::Enum &value,                                                                               \
-                                                       KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                              \
-    {                                                                                                                                                          \
-        group.writeEntry(key, value, flags);                                                                                                                   \
     }
 
 /**
@@ -794,10 +765,6 @@ private:
         const QByteArray M_data = readEntry(key, QByteArray(M_enum.valueToKeys(def)));                                                                         \
         return static_cast<Class::Flags>(M_enum.keysToValue(M_data.constData()));                                                                              \
     }                                                                                                                                                          \
-    inline Class::Flags KCONFIGCORE_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Flags &def)                             \
-    {                                                                                                                                                          \
-        return group.readEntry(key, def);                                                                                                                      \
-    }                                                                                                                                                          \
     template<>                                                                                                                                                 \
     void KConfigGroup::writeEntry(const char *key, const Class::Flags &value, KConfigBase::WriteConfigFlags flags)                                             \
     {                                                                                                                                                          \
@@ -807,29 +774,22 @@ private:
             qFatal(KCONFIGGROUP_ENUMERATOR_ERROR(#Flags));                                                                                                     \
         const QMetaEnum M_enum = M_obj->enumerator(M_index);                                                                                                   \
         writeEntry(key, QByteArray(M_enum.valueToKeys(value)), flags);                                                                                         \
-    }                                                                                                                                                          \
-    inline void KCONFIGCORE_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                    \
-                                                       const char *key,                                                                                        \
-                                                       const Class::Flags &value,                                                                              \
-                                                       KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                              \
-    {                                                                                                                                                          \
-        group.writeEntry(key, value, flags);                                                                                                                   \
     }
 
-#include "conversioncheck.h"
+#include "kconfigconversioncheck_p.h"
 
 template<typename T>
 T KConfigGroup::readEntry(const char *key, const T &defaultValue) const
 {
-    ConversionCheck::to_QVariant<T>();
+    KConfigConversionCheck::to_QVariant<T>();
     return qvariant_cast<T>(readEntry(key, QVariant::fromValue(defaultValue)));
 }
 
 template<typename T>
 QList<T> KConfigGroup::readEntry(const char *key, const QList<T> &defaultValue) const
 {
-    ConversionCheck::to_QVariant<T>();
-    ConversionCheck::to_QString<T>();
+    KConfigConversionCheck::to_QVariant<T>();
+    KConfigConversionCheck::to_QString<T>();
 
     QVariantList data;
 
@@ -850,15 +810,15 @@ QList<T> KConfigGroup::readEntry(const char *key, const QList<T> &defaultValue)
 template<typename T>
 void KConfigGroup::writeEntry(const char *key, const T &value, WriteConfigFlags pFlags)
 {
-    ConversionCheck::to_QVariant<T>();
+    KConfigConversionCheck::to_QVariant<T>();
     writeEntry(key, QVariant::fromValue(value), pFlags);
 }
 
 template<typename T>
 void KConfigGroup::writeEntry(const char *key, const QList<T> &list, WriteConfigFlags pFlags)
 {
-    ConversionCheck::to_QVariant<T>();
-    ConversionCheck::to_QString<T>();
+    KConfigConversionCheck::to_QVariant<T>();
+    KConfigConversionCheck::to_QString<T>();
     QVariantList data;
     for (const T &value : list) {
         data.append(QVariant::fromValue(value));
